
Welcome to the documentation!
=============================


Introduction
------------

``dask-ngs`` is a Python library for scalable bioinformatics data analysis.

It is built on top of `Dask <https://dask.org>`_ and `Oxbow <https://github.com/abdenlab/oxbow>`_.


.. toctree::
   :maxdepth: 2
   :titlesonly:
   :caption: Contents
   :glob:


API docs
--------

.. automodule:: dask_ngs
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
